@@ -1,7 +1,6 @@
 from django.template import Context, Template
 from django.template.loader import render_to_string
 from django.utils.encoding import force_unicode
-from django.conf import settings
 
 """
 IMPORTANT:
@@ -36,14 +35,11 @@ class SidebarWidget(object):
         template_text --> template that specified in the code itself.
         template_file --> template is a file.
         """
-        if not params:
+        if params:
+            params.update({'widget_title': title})
+        else:
             params = {}
-
-        params.update({
-            'widget_title': title,
-            'STATIC_URL': settings.STATIC_URL,
-            'MEDIA_URL': settings.MEDIA_URL,
-        })
+            params['widget_title'] = title
             
         output = ''
         # We need to anticipate if both template_text and template_file defined
